==> mysql-community_8.3.0.orig.tar.gz: mysql-8.3.0/storage/ndb/src/kernel/vm/VMSignal.cpp <==
/*
   Copyright (c) 2003, 2023, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#include "VMSignal.hpp"
#include <string.h>

#define JAM_FILE_ID 308

Signal::Signal() {
  memset(&header, 0, sizeof(header));
  memset(theData, 0, sizeof(theData));
}

void Signal::garbage_register() {
  int i;
  theData[0] = 0x13579135;
  header.theLength = 0x13579135;
  header.theSendersBlockRef = 0x13579135;
  for (i = 1; i < 24; i++) theData[i] = 0x13579135;
}

==> mysql-community_8.4.0.orig.tar.gz: mysql-8.4.0/storage/ndb/src/kernel/vm/VMSignal.cpp <==
/*
   Copyright (c) 2003, 2024, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#include "VMSignal.hpp"
#include <string.h>

#define JAM_FILE_ID 308

Signal::Signal() {
  memset(&header, 0, sizeof(header));
  memset(theData, 0, sizeof(theData));
}

void Signal::garbage_register() {
  int i;
  theData[0] = 0x13579135;
  header.theLength = 0x13579135;
  header.theSendersBlockRef = 0x13579135;
  for (i = 1; i < 24; i++) theData[i] = 0x13579135;
}
